/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.archives.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.yifu.cloud.plus.v1.yifu.common.mybatis.base.BaseEntity;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * 员工合同
 *
 * @author hgw
 * @date 2022-06-29 20:45:22
 */
@Data
@TableName("t_employee_contract_info")
@EqualsAndHashCode(callSuper = true)
@Schema(description = "员工合同")
public class TEmployeeContrctInfo extends BaseEntity {

    /**
     * 主键
     */
    @TableId(type = IdType.ASSIGN_ID)
    @Schema(description ="主键")
    private String id;

    /**
     * 员工编码
     */
    @Schema(description ="员工编码")
    private String empNo;

    /**
     * 员工主键
     */
    @Schema(description ="员工主键")
    private String empId;

    /**
     * 员工姓名
     */
    @Schema(description ="员工姓名")
    private String empName;

    /**
     * 员工身份证号
     */
    @Schema(description ="员工身份证号")
    private String empIdcard;

    /**
     * 合同名称
     */
    @Schema(description ="合同名称")
    private String contractName;

    /**
     * 合同类型
     */
    @Schema(description ="合同类型")
    private String contractType;

    /**
     * 合同起始时间
     */
    @Schema(description ="合同起始时间")
    private LocalDate contractStart;

    /**
     * 合同到期时间
     */
    @Schema(description ="合同到期时间")
    private LocalDate contractEnd;

    /**
     * 合同主体部门
     */
    @Schema(description ="合同主体部门")
    private String subjectDepart;

    /**
     * 合同主体单位
     */
    @Schema(description ="合同主体单位")
    private String subjectUnit;

    /**
     * 签订情况
     */
    @Schema(description ="签订情况")
    private String situation;

    /**
     * 合同年限
     */
    @Schema(description ="合同年限")
    private Double contractTerm;

    /**
     * 合同编码
     */
    @Schema(description ="合同编码")
    private String contractNo;

    /**
     * remark
     */
    @Schema(description ="remark")
    private String remark;

    /**
     * 是否作废 0否/1是
     */
    @Schema(description ="是否作废 0否/1是")
    private String isObsolete;

    /**
     * 是否归档 0是/1否
     */
    @Schema(description ="是否归档 0是/1否")
    private String isFile;

    /**
     * 数据迁移ID
     */
    @Schema(description ="数据迁移ID")
    private Integer oldId;

    /**
     * 入职日期
     */
    @Schema(description ="入职日期")
    private LocalDateTime enjoinDate;

    /**
     * 合同岗位
     */
    @Schema(description ="合同岗位")
    private String post;

    /**
     * 工时制（数据字典）
     */
    @Schema(description ="工时制（数据字典）")
    private String workingHours;

    /**
     * 档案柜号
     */
    @Schema(description ="档案柜号")
    private String fileCabinetNo;

    /**
     * 结算主体ID
     */
    @Schema(description ="结算主体ID")
    private String settleDomain;

    /**
     * 是否在用：0 是 1 否
     */
    @Schema(description ="是否在用：0 是 1 否")
    private String inUse;

    /**
     * 作废理由
     */
    @Schema(description ="作废理由")
    private String obsoleteReason;

    /**
     * 客户id
     */
    @Schema(description ="客户id")
    private String customerId;

    /**
     * 档案-省
     */
    @Schema(description ="档案-省")
    private Integer fileProvince;

    /**
     * 档案-市
     */
    @Schema(description ="档案-市")
    private Integer fileCity;

    /**
     * 档案-县
     */
    @Schema(description ="档案-县")
    private Integer fileTown;

    /**
     * 0 在职 1 个人离职 2 单位辞退 3 临时 4 特殊人员 5 退休 6 退休返聘
     */
    @Schema(description ="0 在职 1 个人离职 2 单位辞退 3 临时 4 特殊人员 5 退休 6 退休返聘")
    private String workingStatusSub;

    /**
     * 在职状态 0是/1否
     */
    @Schema(description ="在职状态 0是/1否")
    private String workFlag;

    /**
     * 合同试用期开始时间
     */
    @Schema(description ="合同试用期开始时间")
    private LocalDateTime periodStart;

    /**
     * 合同试用期结束时间
     */
    @Schema(description ="合同试用期结束时间")
    private LocalDateTime periodEnd;

    /**
     * 试用期工资 元/月
     */
    @Schema(description ="试用期工资 元/月")
    private BigDecimal periodSalaryPerMonth;

    /**
     * 工资形式 1.计时工资 2.计件工资 3.其他
     */
    @Schema(description ="工资形式 1.计时工资 2.计件工资 3.其他")
    private String salaryType;

    /**
     * 计时工资 工资标准 元/月 
     */
    @Schema(description ="计时工资 工资标准 元/月 ")
    private BigDecimal salaryStandardPerHour;

    /**
     * 计件工资 工资标准单价/元 
     */
    @Schema(description ="计件工资 工资标准单价/元 ")
    private BigDecimal salaryStandardPerPiece;

    /**
     * 派单标识  1 代表派单生成， 派单审核通过后清空标识 专门用于派单作废
     */
    @Schema(description ="派单标识  1 代表派单生成， 派单审核通过后清空标识 专门用于派单作废")
    private String dispatchFlag;

    /**
     * 邮件提醒人id
     */
    @Schema(description ="邮件提醒人id")
    private String warnEmailUserId;

    /**
     * 法大大电子合同标识 0不开通 1开通电子合同
     */
    @Schema(description ="法大大电子合同标识 0不开通 1开通电子合同")
    private String fddFlag;

    /**
     * isSign
     */
    @Schema(description ="isSign")
    private Integer isSign;


}
