/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.archives.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.archives.entity.TEmployeeContrctInfo;
import com.yifu.cloud.plus.v1.yifu.archives.service.TEmployeeContrctInfoService;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * 员工合同
 *
 * @author hgw
 * @date 2022-06-29 20:45:22
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/temployeecontrctinfo")
@Tag(name = "员工合同管理")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class TEmployeeContrctInfoController {

	private final TEmployeeContrctInfoService tEmployeeContrctInfoService;

	/**
	 * 分页查询
	 *
	 * @param page                 分页对象
	 * @param tEmployeeContrctInfo 员工合同
	 * @return
	 */
	@Operation(summary = "分页查询", description = "分页查询")
	@GetMapping("/page")
	@PreAuthorize("@pms.hasPermission('contract_temployeecontrctinfo_get')")
	public R getTEmployeeContrctInfoPage(Page page, TEmployeeContrctInfo tEmployeeContrctInfo) {
		return R.ok(tEmployeeContrctInfoService.page(page, Wrappers.query(tEmployeeContrctInfo)));
	}


	/**
	 * 通过id查询员工合同
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('contract_temployeecontrctinfo_get')")
	@GetMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('contract_temployeecontrctinfo_get')")
	public R getById(@PathVariable("id") String id) {
		return R.ok(tEmployeeContrctInfoService.getById(id));
	}

	/**
	 * 新增员工合同
	 *
	 * @param tEmployeeContrctInfo 员工合同
	 * @return R
	 */
	@Operation(summary = "新增员工合同", description = "新增员工合同：hasPermission('contract_temployeecontrctinfo_add')")
	@SysLog("新增员工合同")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('contract_temployeecontrctinfo_add')")
	public R save(@RequestBody TEmployeeContrctInfo tEmployeeContrctInfo) {
		return R.ok(tEmployeeContrctInfoService.save(tEmployeeContrctInfo));
	}

	/**
	 * 修改员工合同
	 *
	 * @param tEmployeeContrctInfo 员工合同
	 * @return R
	 */
	@Operation(summary = "修改员工合同", description = "修改员工合同：hasPermission('contract_temployeecontrctinfo_edit')")
	@SysLog("修改员工合同")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('contract_temployeecontrctinfo_edit')")
	public R updateById(@RequestBody TEmployeeContrctInfo tEmployeeContrctInfo) {
		return R.ok(tEmployeeContrctInfoService.updateById(tEmployeeContrctInfo));
	}

	/**
	 * 通过id删除员工合同
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除员工合同", description = "通过id删除员工合同：hasPermission('contract_temployeecontrctinfo_del')")
	@SysLog("通过id删除员工合同")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('contract_temployeecontrctinfo_del')")
	public R removeById(@PathVariable String id) {
		return R.ok(tEmployeeContrctInfoService.removeById(id));
	}

}
